@@ -43,7 +43,7 @@ readKH <- function(file,
   party <- as.numeric(substring(data,21,23))
   ## convert party to label
   partyfunc <- function(x){
-    data(partycodes)
+    ##data(partycodes)
     party <- partycodes$party[match(x,partycodes$code)]
     party[party=="Democrat"] <- "D"
     party[party=="Republican"] <- "R"
@@ -54,13 +54,13 @@ readKH <- function(file,
 
   ## convert state ICPSR code to abbreviation
   statename <- function(x){
-    data(state.info)
+    ##data(state.info)
     state.info$state[match(x,state.info$icpsr)]
   }
   state <- as.numeric(substring(data,9,10))  ## icpsr code
   KHstateName <- substring(data,13,20)
   stateName <- statename(state)  ## covert to name
-  stateAbb <- state.abb[match(stateName,state.name)]  ## convert to abbrev
+  stateAbb <- datasets::state.abb[match(stateName,datasets::state.name)]  ## convert to abbrev
   stateAbb[grep(KHstateName,pattern="^USA")] <- "USA"  ## for presidents
 
   cd <- as.numeric(substring(data,11,12))
