@@ -151,7 +151,7 @@ zeroinfl <- function(formula, data, subset, na.action, weights, offset,
     ffz <- ffc <- ff <- formula
     ffz[[2]] <- NULL
   }
-  if(length(grep("in formula and no", try(terms(ffz), silent = TRUE), fixed = TRUE)) > 0) {
+  if(inherits(try(terms(ffz), silent = TRUE), "try-error")) {
     ffz <- eval(parse(text = sprintf( paste("%s -", deparse(ffc[[2]])), deparse(ffz) )))
   }
 
@@ -160,7 +160,7 @@ zeroinfl <- function(formula, data, subset, na.action, weights, offset,
   mf <- eval(mf, parent.frame())
   
   ## extract terms, model matrices, response
-  mt <- terms(formula, data = data)
+  mt <- attr(mf, "terms")
   mtX <- terms(ffc, data = data)
   X <- model.matrix(mtX, mf)
   mtZ <- terms(ffz, data = data)
@@ -278,15 +278,15 @@ zeroinfl <- function(formula, data, subset, na.action, weights, offset,
 
       ll_new <- loglikfun(c(start$count, start$zero))
       ll_old <- 2 * ll_new      
-      if(!require("MASS")) {
-        ll_old <- ll_new
-	warning("EM estimation of starting values not available")
-      }
+      ##if(!require("MASS")) {
+      ##  ll_old <- ll_new
+      ##	warning("EM estimation of starting values not available")
+      ## }
     
       while(abs((ll_old - ll_new)/ll_old) > control$reltol) {
         ll_old <- ll_new
         model_count <- suppressWarnings(glm.fit(X, Y, weights = weights * (1-probi),
-	  offset = offsetx, family = negative.binomial(1), start = start$count))
+	  offset = offsetx, family = MASS::negative.binomial(1), start = start$count))
         model_zero <- suppressWarnings(glm.fit(Z, probi, weights = weights,
 	  offset = offsetz, family = binomial(link = linkstr), start = start$zero))
         start <- list(count = model_count$coefficients, zero = model_zero$coefficients)
@@ -306,10 +306,10 @@ zeroinfl <- function(formula, data, subset, na.action, weights, offset,
 
       ll_new <- loglikfun(c(start$count, start$zero, log(start$theta)))      
       ll_old <- 2 * ll_new      
-      if(!require("MASS")) {
-        ll_old <- ll_new
-	warning("EM estimation of starting values not available")
-      }
+      ## if(!require("MASS")) {
+      ##   ll_old <- ll_new
+      ##   warning("EM estimation of starting values not available")
+      ## }
       
       ## offset handling in glm.nb is sub-optimal, hence...
       offset <- offsetx
@@ -528,7 +528,7 @@ print.summary.zeroinfl <- function(x, digits = max(3, getOption("digits") - 3),
 }
 
 predict.zeroinfl <- function(object, newdata, type = c("response", "prob", "count", "zero"),
-  na.action = na.pass, ...)
+  na.action = na.pass, at = NULL, ...)
 {
     type <- match.arg(type)
 
@@ -575,7 +575,7 @@ predict.zeroinfl <- function(object, newdata, type = c("response", "prob", "coun
         else if(!is.null(object$model)) y <- model.response(object$model)
 	else stop("predicted probabilities cannot be computed for fits with y = FALSE and model = FALSE")
 
-      yUnique <- min(y):max(y)
+      yUnique <- if(is.null(at)) 0:max(y) else at
       nUnique <- length(yUnique)
       rval <- matrix(NA, nrow = length(rval), ncol = nUnique)
       dimnames(rval) <- list(rownames(X), yUnique)
